searchData={"items":[{"type":"module","title":"Mockable","doc":"Documentation for `Mockable`.","ref":"Mockable.html"},{"type":"function","title":"Mockable.log_implementation_usage/4","doc":"","ref":"Mockable.html#log_implementation_usage/4"},{"type":"function","title":"Mockable.use/2","doc":"Configures which module to use for a given mockable module.\nIf no implementation is provided, the mockable module itself will be used.\n\nThis is useful for testing your Mockable module.\n\n```elixir\nMockable.use(Client)\n```\n\nOr to use a specific implementation:\n```elixir\nMockable.use(Client, ClientMock)\n```\n\nThis function stores the configuration in process memory so that it is compatible with async tests.","ref":"Mockable.html#use/2"},{"type":"extras","title":"Mockable","doc":"# Mockable\n\n[![Build Status](https://github.com/grantwest/mockable/actions/workflows/ci.yml/badge.svg)](https://github.com/grantwest/mockable/actions/workflows/ci.yml)\n[![Version](https://img.shields.io/hexpm/v/mockable.svg)](https://hex.pm/packages/mockable)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/mockable/)\n[![Download](https://img.shields.io/hexpm/dt/mockable.svg)](https://hex.pm/packages/mockable)\n[![License](https://img.shields.io/badge/License-0BSD-blue.svg)](https://opensource.org/licenses/0bsd)\n[![Last Updated](https://img.shields.io/github/last-commit/grantwest/mockable.svg)](https://github.com/grantwest/mockable/commits/main)\n\nZero boilerplate mock delegation.","ref":"readme.html"},{"type":"extras","title":"Example - Mockable","doc":"use Mockable in a module:\n\n```elixir\ndefmodule TemperatureClient do\n  use Mockable\n\n  @callback get_temperature(String.t()) :: integer()\n\n  @impl true\n  def get_temperature(city) do\n    Req.get!(\"https://weather.com/temperatue/#{city}\").body[\"temperature\"]\n  end\nend\n```\n\nConfigure the test environment (config/test.exs) to delegate function calls to the mock:\n\n```elixir\nconfig :mockable, [\n  {TemperatureClient, TemperatureClientMock}\n]\n```\n\nOptionally configure the dev environment (config/dev.exs) to delegate function calls to a stub:\n\n```elixir\nconfig :mockable, [\n  {TemperatureClient, TemperatureClientStub},\n  log: false\n]\n```\n\nThe `log` option shown above controls whether a log is emmitted for each invocation indicating the implementation used. If you are using mockable in prod builds for stubs/fakes in staging environments, you probably want to set `log: false` for your prod build.\n\nIf you don't configure a default implementation for a Mockable module at compile time, all Mockable code for that module will be completely eliminated from the build. It will be as if that module does not `use Mockable`.\n\nImplement a dev stub like this:\n\n```elixir\ndefmodule TemperatureClientStub do\n  @behaviour TemperatureClient\n\n  @impl true\n  def get_temperature(city) do\n    30\n  end\nend\n```\n\n[See docs](https://hexdocs.pm/mockable/Mockable.html) for more information and examples.","ref":"readme.html#example"},{"type":"extras","title":"Details - Mockable","doc":"Mockable works by using a `__before_compile__` macro to wrap each callback implementation in delegation logic. But it only does this if `:mockable` is configured, thus it does not affect production code.\n\nFeatures/Benefits:\n\n- Zero boilerplate code\n- Can be used with Exunit `async: true`\n- Compatible with Mox/Hammox (and probably any other mocking library)\n- Applies @callback as @spec on implementations to enable dialyzer checks\n- Configurable with Application environment & process memory\n- Completely compiles out in prod builds, not requiring even an `Application.get_env`, making it suitable for frequently called functions\n- Behaviour and implementation defined in the same module for easy finding/reading\n- Only overrides callbacks, other functions defined within the Mockable module are not delegated and can be called as normal","ref":"readme.html#details"},{"type":"extras","title":"CHANGELOG","doc":"# CHANGELOG","ref":"changelog.html"},{"type":"extras","title":"v0.2.1 (2025-06-06) - CHANGELOG","doc":"- Compile out mockable for individual Mockable modules instead of globally, to support stubs/fakes in prod builds for staging environments","ref":"changelog.html#v0-2-1-2025-06-06"},{"type":"extras","title":"v0.2.0 (2025-06-05) - CHANGELOG","doc":"- Creating @spec on mockable functions using @callback\n- `log: true/false` is now compile time configuration","ref":"changelog.html#v0-2-0-2025-06-05"}],"content_type":"text/markdown"}